<?php
ini_set("display_errors", 1);
if (!defined('BASEPATH'))
	exit('No direct script access allowed');


class Md_pringles extends CI_Model {

	public function newClient($nombre, $telefono, $bot_user, $pais) {

		$otherdb = $this->load->database('pringles', TRUE);

		$data3 = array(
				'nombre' => $nombre,
				'telefono' => $telefono,
				'bot_user' => $bot_user,
				'pais' => $pais,
				'fecha' => date("Y-m-d H:i:s"),
		);
		$otherdb->insert('clients', $data3);

		$insert_id = $otherdb->insert_id();
		return $insert_id;
	}

	public function newCompra($telefono, $foto) {

		$otherdb = $this->load->database('pringles', TRUE);
		
		$otherdb->select('*');
		$otherdb->from('clients');
		$otherdb->where('telefono', $telefono);
		$test_usr = $otherdb->get()->result_array();
		error_log(json_encode($test_usr));

		if( !empty($test_usr) ) {

			$data3 = array(
					'clients_id' => $test_usr[0]['id'],
					'foto_de_tienda' => $foto,
					'status' => 0,
					'fecha' => date("Y-m-d H:i:s"),
			);
			$otherdb->insert('compra', $data3);

			$insert_id = $otherdb->insert_id();
			return $insert_id;
		} else {
			return FALSE;
		}
	}

	public function newFoto($telefono, $foto) {

		$otherdb = $this->load->database('pringles', TRUE);
		
		$otherdb->select('*');
		$otherdb->from('clients');
		$otherdb->where('telefono', $telefono);
		$test_usr = $otherdb->get()->result_array();

		if( !empty($test_usr) ) {

			$otherdb = $this->load->database('pringles', TRUE);
		
			$otherdb->select('*');
			$otherdb->from('compra');
			$otherdb->where('clients_id', $test_usr[0]['id']);
			$otherdb->where('status', 0);
			$test_compra = $otherdb->get()->result_array();
	
			if( !empty($test_compra) ) {
	
				$data3 = array(
						'compra_id' => $test_compra[0]['id'],
						'foto' => $foto,
						'fecha' => date("Y-m-d H:i:s"),
				);
				$otherdb->insert('fotos', $data3);
	
				$insert_id = $otherdb->insert_id();
				return $insert_id;
			}
		} else {
			return FALSE;
		}
	}

	public function updateCompra($telefono, $status) {

		$otherdb = $this->load->database('pringles', TRUE);
		
		$otherdb->select('*');
		$otherdb->from('clients');
		$otherdb->where('telefono', $telefono);
		$test_usr = $otherdb->get()->result_array();

		if( !empty($test_usr) ) {

			$otherdb = $this->load->database('pringles', TRUE);
		
			$otherdb->select('*');
			$otherdb->from('compra');
			$otherdb->where('clients_id', $test_usr[0]['id']);
			$otherdb->where('status', 0);
			$test_compra = $otherdb->get()->result_array();
	
			if( !empty($test_compra) ) {
	

				$data3 = array(
					'status' => $status,
				);
				$otherdb->where('id', $test_compra[0]['id']);

				$otherdb->update('compra', $data3);

			}
		} else {
			return FALSE;
		}
	}

}
